/// <reference types="koa" />
import { Middleware } from 'koa';
import { IConfiguration } from './IConfiguration';
import { MvcSymbols } from './util/index';
import { IContainer, IContainerBuilder, Type, Token, AsyncLoadOptions } from '@ts-ioc/core';
import { Application, IMiddleware } from './core';
import { IServerMiddleware, ServerMiddleware } from './core/servers/index';
/**
 * mvc applaction bootstrap.
 *
 * @export
 * @class Bootstrap
 */
export declare class Bootstrap {
    private rootdir;
    protected appType: Type<Application>;
    private beforeSMdls;
    private afterSMdls;
    private container;
    private middlewares;
    private configDefer;
    private builder;
    /**
     * Creates an instance of WebApplication.
     * @param {string} rootdir
     * @param {Type<any>} [appType]
     * @memberof WebApplication
     */
    constructor(rootdir: string, appType?: Type<Application>);
    static symbols: MvcSymbols;
    /**
     * create new application.
     *
     * @static
     * @param {string} rootdir
     * @param {Type<Application>} [appType]
     * @returns
     * @memberof WebApplication
     */
    static create(rootdir: string, appType?: Type<Application>): Bootstrap;
    /**
     * user custom IContainer.
     *
     * @param {(IContainer | Promise<IContainer>)} [container]
     * @returns
     *
     * @memberOf WebHostBuilder
     */
    useContainer(container: IContainer | Promise<IContainer>): this;
    /**
     * get container of bootstrap.
     *
     * @returns
     * @memberof Bootstrap
     */
    getContainer(): Promise<IContainer>;
    protected createContainer(option?: AsyncLoadOptions): Promise<IContainer>;
    /**
     * use container builder
     *
     * @param {IContainerBuilder} builder
     * @returns
     * @memberof Bootstrap
     */
    useContainerBuilder(builder: IContainerBuilder): this;
    /**
     * get container builder.
     *
     * @returns
     * @memberof Bootstrap
     */
    getContainerBuilder(): IContainerBuilder;
    /**
     * use custom configuration.
     *
     * @param {(string | IConfiguration)} [config]
     * @returns {this}
     * @memberof Bootstrap
     */
    useConfiguration(config?: string | IConfiguration): this;
    /**
     * get configuration.
     *
     * @returns {Promise<IConfiguration>}
     * @memberof Bootstrap
     */
    getConfiguration(): Promise<IConfiguration>;
    /**
     * use middleware `fn` or  `MiddlewareFactory`.
     *
     * @param {(IMiddleware | Middleware | Token<any>)} middleware
     * @returns {this}
     * @memberof Bootstrap
     */
    use(middleware: IMiddleware | Middleware | Token<any>): this;
    useServer(middleware: ServerMiddleware | Token<IServerMiddleware>, afterMvc?: boolean): this;
    /**
     * run service.
     *
     * @param {Function} [listener]
     * @returns
     * @memberof Bootstrap
     */
    run(listener?: Function): Promise<Application>;
    /**
     * build application.
     * @returns {Bootstrap}
     * @memberOf WebHostBuilder
     */
    protected build(): Promise<Application>;
    protected initIContainer(config: IConfiguration, container: IContainer): Promise<IContainer>;
    protected registerDefaultMiddlewars(container: IContainer): void;
    protected registerDefaults(container: IContainer): void;
    protected setupRoutes(config: IConfiguration, container: IContainer): void;
    protected setupMiddwares(app: Application, container: IContainer, middlewares: Token<any>[], excludes: Token<any>[]): Application;
    protected setupServerMiddwares(app: Application, container: IContainer, middlewares: (ServerMiddleware | Token<IServerMiddleware>)[]): void;
    static classAnnations: any;
}
