import { IClassMethodDecorator, ClassMethodDecorator, MetadataAdapter, MetadataExtends } from '@ts-ioc/core';
import { CorsMetadata } from '../metadata/index';
import { RequestMethod } from '../RequestMethod';
/**
 * Cors Decorator, define controller class or controller method support cors request.
 * @Cors
 *
 * @export
 * @interface ICorsDecorator
 * @extends {IClassMethodDecorator<T>}
 * @template T
 */
export interface ICorsDecorator<T extends CorsMetadata> extends IClassMethodDecorator<T> {
    /**
     * Cors Decorator, define controller class or controller method support cors.
     * @Cors
     *
     * @param {(string | string[] | RequestMethod[])} [allowMethods] allow request methods cors, 'Access-Control-Expose-Headers'.
     * @param {number} [maxAge] set cors cache max age,  Access-Control-Max-Age.
     * @param {(string | string[])} [allowHeaders] allow cors request headers, 'Access-Control-Request-Headers'.
     */
    (allowMethods?: string | string[] | RequestMethod[], maxAge?: number, allowHeaders?: string | string[]): ClassMethodDecorator;
    /**
     * Cors Decorator, define controller class or controller method support cors.
     * @Cors
     *
     * @param {T} [metadata] define metadata.
     */
    (metadata: T): ClassMethodDecorator;
}
/**
 * Cors Decorator, define controller class or controller method support cors.
 * @Cors
 * @param name
 * @param adapter
 * @param metadataExtends
 */
export declare function createCorsDecorator<T extends CorsMetadata>(name: string, adapter?: MetadataAdapter, metadataExtends?: MetadataExtends<T>): ICorsDecorator<T>;
/**
 * Cors Decorator, define controller class or controller method support cors.
 * @Cors
 */
export declare const Cors: ICorsDecorator<CorsMetadata>;
