import { IMethodDecorator, MetadataExtends, MetadataAdapter } from '@ts-ioc/core';
import { RequestMethod } from '../RequestMethod';
import { RouteMetadata } from '../metadata/index';
/**
 * custom define Request method. route decorator type define.
 *
 * @export
 * @interface IRouteMethodDecorator
 * @template T
 */
export interface IRouteMethodDecorator<T extends RouteMetadata> extends IMethodDecorator<T> {
    /**
     * route decorator. define the controller method as an route.
     *
     * @param {string} route route sub path.
     * @param {string} [contentType] set request contentType.
     * @param {RequestMethod} [method] set request method.
     */
    (route: string, contentType?: string, method?: RequestMethod): MethodDecorator;
}
/**
 * create route decorator.
 *
 * @export
 * @template T
 * @param {RequestMethod} [method]
 * @param { MetadataExtends<T>} [metaExtends]
 */
export declare function createRouteDecorator<T extends RouteMetadata>(method?: RequestMethod, adapter?: MetadataAdapter, metaExtends?: MetadataExtends<T>): IRouteMethodDecorator<T>;
/**
 * route decorator. define the controller method as an route.
 *
 * @Route
 */
export declare const Route: IRouteMethodDecorator<RouteMetadata>;
